# Generated by Django 6.0 on 2025-01-28 23:32

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_facility", "0014_healthfacility_title_historicalhealthfacility_title"),
        ("meta_subject", "0216_historicalnextappointment_nextappointment"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="appt_datetime",
            field=models.DateTimeField(
                help_text="Should fall on an valid clinic day for this facility",
                null=True,
                verbose_name="Next scheduled routine/facility appointment date and time",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="appt_datetime",
            field=models.DateTimeField(
                help_text="Should fall on an valid clinic day for this facility",
                null=True,
                verbose_name="Next scheduled routine/facility appointment date and time",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="health_facility",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_facility.healthfacility",
            ),
        ),
    ]
