# Generated by Django 5.0.8 on 2024-08-21 22:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0023_endpoints_meta_report_subject_a56b22_idx"),
    ]

    operations = [
        migrations.CreateModel(
            name="GlucoseSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("report_model", models.CharField(max_length=50)),
                ("subject_identifier", models.CharField(max_length=25)),
                ("created", models.DateTimeField()),
                ("fbg_value", models.DecimalField(decimal_places=2, max_digits=8, null=True)),
                ("fbg_datetime", models.DateTimeField(null=True)),
                ("ogtt_value", models.DecimalField(decimal_places=2, max_digits=8, null=True)),
                ("ogtt_datetime", models.DateTimeField(null=True)),
            ],
            options={
                "verbose_name": "GlucoseSummary",
                "verbose_name_plural": "GlucoseSummary",
                "db_table": "glucose_summary_view",
                "managed": False,
                "default_permissions": ("view", "export", "viewallsites"),
            },
        ),
    ]
