# Generated by Django 4.2.10 on 2024-03-08 02:14

from django.db import migrations, models
import edc_model_fields.fields.other_charfield


class Migration(migrations.Migration):

    dependencies = [
        ("meta_lists", "0018_missedreferralreasons"),
        ("meta_subject", "0179_alter_birthoutcomes_consent_model_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="dmreferralfollowup",
            name="missed_referral_reasons",
            field=models.ManyToManyField(
                blank=True,
                to="meta_lists.missedreferralreasons",
                verbose_name="If 'No', please provide a reason for not seeking further care or follow up?",
            ),
        ),
        migrations.AddField(
            model_name="dmreferralfollowup",
            name="other_missed_referral_reason",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other 'reason for not seeking further care', please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicaldmreferralfollowup",
            name="other_missed_referral_reason",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other 'reason for not seeking further care', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="dmreferralfollowup",
            name="not_attended_reason",
            field=models.TextField(
                default="QUESTION_RETIRED",
                editable=False,
                verbose_name="If 'No', please provide a reason for not seeking further care or follow up?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmreferralfollowup",
            name="not_attended_reason",
            field=models.TextField(
                default="QUESTION_RETIRED",
                editable=False,
                verbose_name="If 'No', please provide a reason for not seeking further care or follow up?",
            ),
        ),
    ]
