# Generated by Django 3.0.6 on 2020-05-16 22:25

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0033_auto_20200516_2356"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="historicalmissedvisit",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Missed Visit Report",
            },
        ),
        migrations.AlterModelOptions(
            name="missedvisit",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Missed Visit Report",
                "verbose_name_plural": "Missed Visit Report",
            },
        ),
    ]
