# Generated by Django 6.0 on 2025-04-15 22:06

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0221_auto_20250402_1913"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="stock_codes",
            field=models.TextField(
                blank=True,
                help_text="Enter the medication bottle barcode or barcodes. Type one code per line",
                max_length=30,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Enter one or more valid codes, one code per line",
                        regex="^([A-Z0-9]{6})(\r\n[A-Z0-9]{6})*$",
                    )
                ],
            ),
        ),
        migrations.AlterField(
            model_name="studymedication",
            name="stock_codes",
            field=models.TextField(
                blank=True,
                help_text="Enter the medication bottle barcode or barcodes. Type one code per line",
                max_length=30,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Enter one or more valid codes, one code per line",
                        regex="^([A-Z0-9]{6})(\r\n[A-Z0-9]{6})*$",
                    )
                ],
            ),
        ),
    ]
