# Generated by Django 5.2.10 on 2026-01-23 14:00

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_lists", "0021_diagnosticdevices"),
        ("meta_subject", "0241_remove_glucose_diagnostic_device_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="glucose",
            name="ogtt_diagnostic_device",
            field=models.ForeignKey(
                limit_choices_to={"name__in": ["accuchek", "hemocue", "OTHER", "N/A"]},
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="ogtt_diagnostic_device",
                to="meta_lists.diagnosticdevices",
            ),
        ),
        migrations.AddField(
            model_name="historicalglucose",
            name="ogtt_diagnostic_device",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"name__in": ["accuchek", "hemocue", "OTHER", "N/A"]},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="meta_lists.diagnosticdevices",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="fbg_diagnostic_device",
            field=models.ForeignKey(
                limit_choices_to={"name__in": ["accuchek", "hemocue", "OTHER", "N/A"]},
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="fbg_diagnostic_device",
                to="meta_lists.diagnosticdevices",
            ),
        ),
        migrations.AlterField(
            model_name="glucosefbg",
            name="fbg_diagnostic_device",
            field=models.ForeignKey(
                limit_choices_to={"name__in": ["accuchek", "hemocue", "OTHER", "N/A"]},
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="meta_lists.diagnosticdevices",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="fbg_diagnostic_device",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"name__in": ["accuchek", "hemocue", "OTHER", "N/A"]},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="meta_lists.diagnosticdevices",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucosefbg",
            name="fbg_diagnostic_device",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"name__in": ["accuchek", "hemocue", "OTHER", "N/A"]},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="meta_lists.diagnosticdevices",
            ),
        ),
    ]
