from .health_economics_simple_form import HealthEconomicsSimpleForm
from .health_economics_update_form import HealthEconomicsUpdateForm

__all__ = ["HealthEconomicsSimpleForm", "HealthEconomicsUpdateForm"]
