# Generated by Django 5.2.3 on 2025-07-03 22:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0064_auto_20250602_2143"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicaloffstudymedication",
            name="subject_identifier",
            field=models.CharField(db_index=True, max_length=50),
        ),
        migrations.AlterField(
            model_name="offstudymedication",
            name="subject_identifier",
            field=models.CharField(max_length=50, unique=True),
        ),
    ]
