# Generated by Django 5.1 on 2024-09-11 00:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_pharmacy", "0003_auto_20240909_2335"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubstitutions",
            name="report_datetime",
            field=models.DateTimeField(null=True),
        ),
        migrations.AlterField(
            model_name="substitutions",
            name="report_datetime",
            field=models.DateTimeField(null=True),
        ),
    ]
