# Generated by Django 5.2.7 on 2025-10-24 04:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_consent", "0034_remove_subjectconsentspfq_site_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="consent_definition_name",
            field=models.CharField(
                default="",
                editable=False,
                max_length=50,
                verbose_name="Consent definition",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="consent_definition_name",
            field=models.CharField(
                default="",
                editable=False,
                max_length=50,
                verbose_name="Consent definition",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="consent_definition_name",
            field=models.CharField(
                default="",
                editable=False,
                max_length=50,
                verbose_name="Consent definition",
            ),
        ),
    ]
