# Generated by Django 5.2.6 on 2025-09-30 00:38

import _socket
import django.core.validators
import django.db.models.deletion
import django.utils.timezone
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_revision.revision_field
import edc_crf.model_mixins.crf_status_model_mixin
import edc_model.models.fields.initials_field
import edc_model.validators.date
import edc_model_fields.fields.other_charfield
import edc_protocol.validators
import edc_visit_tracking.managers
import simple_history.models
import uuid
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0230_alter_historicaldelivery_action_identifier_and_more"),
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="pill_count_not_performed_reason",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If not performed, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="mnsi_not_performed_reason",
            field=models.TextField(
                blank=True,
                default="",
                max_length=200,
                verbose_name="If NO, please provide a reason",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimensdetail",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimensdetail",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimensdetail",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimensdetail",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimensdetail",
            name="notes",
            field=models.CharField(
                blank=True, default="", max_length=100, verbose_name="Notes"
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimensdetail",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="concomitant_conditions",
            field=models.TextField(
                blank=True,
                default="",
                max_length=250,
                verbose_name="Does the patient have any other conditions not mentioned above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="concomitant_medications",
            field=models.TextField(
                blank=True,
                default="",
                max_length=250,
                verbose_name="Is the patient taking any concomitant medications?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="dyslipidaemia_diagnosis",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Has the patient been diagnosed with dyslipidaemia?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="other_dm_symptoms",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=35,
                verbose_name="If other symptom in the <u>past year</u>, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="other_dyslipidaemia_rx",
            field=models.CharField(
                blank=True,
                default="",
                max_length=50,
                verbose_name="What medication is the patient currently taking for dyslipidaemia?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="abdominal_tenderness_description",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If YES, abdominal tenderness, please describe",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="irregular_heartbeat_description",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If the heartbeat is <u>irregular</u>, please describe",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/110mmHg",
                max_length=15,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="waist_circumference_comment",
            field=models.TextField(
                blank=True,
                default="",
                help_text="A reason not measured may be provided at anytime but is required at 36 and 48 months",
                verbose_name="If waist circumference not measured, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="comment",
            field=models.TextField(default="", verbose_name="Comment / Updates"),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="special_instructions",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="stock_codes",
            field=models.TextField(
                blank=True,
                default="",
                help_text="Enter the medication bottle barcode or barcodes. Type one code per line",
                max_length=30,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Enter one or more valid codes, one code per line",
                        regex="^([A-Z0-9]{6})(\r\n[A-Z0-9]{6})*$",
                    )
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="clinic_verified",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")], default="", max_length=15
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="clinician_initials",
            field=edc_model.models.fields.initials_field.InitialsField(
                blank=True,
                default="",
                help_text="Type 2-3 letters, all in uppercase and no spaces",
                max_length=3,
                verbose_name="Initials",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="comments",
            field=models.TextField(blank=True, default="", max_length=25),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="protocol_number",
            field=models.CharField(default="", editable=False, max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="specimen_type",
            field=models.CharField(
                blank=True, default="", max_length=25, verbose_name="Specimen type"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="comments",
            field=models.TextField(
                blank=True,
                default="",
                max_length=250,
                verbose_name="Comment if any additional pertinent information about the participant",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="document_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this document",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="info_source_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=35,
                verbose_name='If "Other" source of information, specify',
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="reason_missed",
            field=models.CharField(
                blank=True,
                default="",
                max_length=35,
                verbose_name="If 'missed', provide the reason for the missed visit",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="reason_missed_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=25,
                verbose_name='If the reason for the missed visit is "other", specify',
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="Date and time of this report",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="study_status",
            field=models.CharField(
                default="",
                max_length=50,
                verbose_name="What is the participant's current study status",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="survival_status",
            field=models.CharField(
                choices=[
                    ("alive", "Alive"),
                    ("dead", "Deceased"),
                    ("unknown", "Unknown"),
                    ("N/A", "Not applicable (if missed)"),
                ],
                default="alive",
                help_text="If YES, submit Death report",
                max_length=10,
                verbose_name="Participant's survival status",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="unschedule_detail",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If 'unschedule', please provide further details, if any",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="visit_code",
            field=models.CharField(default="", editable=False, max_length=25),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="action_identifier",
            field=models.CharField(blank=True, db_index=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="comment",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="Please provide further details, if any",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="contact_attempts_explained",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If contact not made and less than 3 attempts, please explain",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="not_performed_reason",
            field=models.CharField(
                blank=True,
                default="",
                max_length=150,
                verbose_name="If NO, provide reason",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="action_identifier",
            field=models.CharField(blank=True, db_index=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="not_performed_reason",
            field=models.CharField(
                blank=True,
                default="",
                max_length=150,
                verbose_name="If NO, provide reason",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="not_performed_reason",
            field=models.CharField(
                blank=True,
                default="",
                max_length=150,
                verbose_name="If NO, provide reason",
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="pill_count_not_performed_reason",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If not performed, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="mnsi_not_performed_reason",
            field=models.TextField(
                blank=True,
                default="",
                max_length=200,
                verbose_name="If NO, please provide a reason",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimensdetail",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimensdetail",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimensdetail",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimensdetail",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimensdetail",
            name="notes",
            field=models.CharField(
                blank=True, default="", max_length=100, verbose_name="Notes"
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimensdetail",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
    ]
