{% load i18n %}
<span style="color:orange;font-weight:bold">Note: </span> {% trans "Detailed information about study termination will be asked for on the" %} <b>{{ verbose_name }}</b> {% trans "form" %}
