# Generated by Django 6.0 on 2025-04-22 19:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0054_auto_20250422_2003"),
    ]

    operations = [
        migrations.AlterModelTable(
            name="glucosesummary",
            table="meta_reports_glucosesummaryview",
        ),
    ]
