# Generated by Django 4.2.11 on 2024-05-15 23:20

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0191_alter_dmdiagnosis_dx_no_tmg_reason_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="glucosefbg",
            old_name="glucose_quantifier",
            new_name="fbg_quantifier",
        ),
        migrations.RenameField(
            model_name="glucosefbg",
            old_name="glucose_units",
            new_name="fbg_units",
        ),
        migrations.RenameField(
            model_name="historicalglucosefbg",
            old_name="glucose_quantifier",
            new_name="fbg_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalglucosefbg",
            old_name="glucose_units",
            new_name="fbg_units",
        ),
        migrations.RenameField(
            model_name="glucosefbg",
            old_name="glucose_value",
            new_name="fbg_value",
        ),
        migrations.RenameField(
            model_name="historicalglucosefbg",
            old_name="glucose_value",
            new_name="fbg_value",
        ),
    ]
