# Generated by Django 2.2.6 on 2019-10-20 04:38

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("meta_screening", "0003_auto_20191020_0627")]

    operations = [
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="creatinine",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Serum creatinine levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="hba1c",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in %",
                max_digits=8,
                null=True,
                verbose_name="HbA1c",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="ogtt_two_hr",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(300),
                ],
                verbose_name="Blood glucose levels 2-hours after glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="ogtt_two_hr_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                editable=False,
                max_length=15,
                verbose_name="Units (Blood glucose)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="weight",
            field=models.DecimalField(
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="creatinine",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Serum creatinine levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="hba1c",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in %",
                max_digits=8,
                null=True,
                verbose_name="HbA1c",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="ogtt_two_hr",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(300),
                ],
                verbose_name="Blood glucose levels 2-hours after glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="ogtt_two_hr_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                editable=False,
                max_length=15,
                verbose_name="Units (Blood glucose)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="weight",
            field=models.DecimalField(
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="creatinine",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Serum creatinine levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="hba1c",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in %",
                max_digits=8,
                null=True,
                verbose_name="HbA1c",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="ogtt_two_hr",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(300),
                ],
                verbose_name="Blood glucose levels 2-hours after glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="ogtt_two_hr_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                editable=False,
                max_length=15,
                verbose_name="Units (Blood glucose)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="weight",
            field=models.DecimalField(
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="creatinine",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Serum creatinine levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="hba1c",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in %",
                max_digits=8,
                null=True,
                verbose_name="HbA1c",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="ogtt_two_hr",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(300),
                ],
                verbose_name="Blood glucose levels 2-hours after glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="ogtt_two_hr_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                editable=False,
                max_length=15,
                verbose_name="Units (Blood glucose)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="weight",
            field=models.DecimalField(
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="creatinine",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Serum creatinine levels",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="hba1c",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in %",
                max_digits=8,
                null=True,
                verbose_name="HbA1c",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="ogtt_two_hr",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(300),
                ],
                verbose_name="Blood glucose levels 2-hours after glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="ogtt_two_hr_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                editable=False,
                max_length=15,
                verbose_name="Units (Blood glucose)",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="weight",
            field=models.DecimalField(
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
    ]
