# Generated by Django 3.0.4 on 2020-04-22 17:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0030_auto_20200420_1816"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="coronakap",
            name="shared_housing_one",
        ),
        migrations.RemoveField(
            model_name="coronakap",
            name="shared_housing_two",
        ),
        migrations.RemoveField(
            model_name="historicalcoronakap",
            name="shared_housing_one",
        ),
        migrations.RemoveField(
            model_name="historicalcoronakap",
            name="shared_housing_two",
        ),
        migrations.AddField(
            model_name="coronakap",
            name="diabetic_missed_doses",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>diabetes</u> medications?",
            ),
        ),
        migrations.AddField(
            model_name="coronakap",
            name="hiv_missed_doses",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>ART</u> medications?",
            ),
        ),
        migrations.AddField(
            model_name="coronakap",
            name="household_size",
            field=models.IntegerField(
                default=2,
                help_text="Family / people who spend more than 14 nights per month in your home.",
                verbose_name="How many people live together in your home / dwelling?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="coronakap",
            name="hypertensive_missed_doses",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>hypertension</u> medications?",
            ),
        ),
        migrations.AddField(
            model_name="coronakap",
            name="nights_away",
            field=models.IntegerField(
                default=0,
                help_text="e.g. travelling for work, staying with family",
                verbose_name="In the last one month, how many nights did you spend away from your home / dwelling?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalcoronakap",
            name="diabetic_missed_doses",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>diabetes</u> medications?",
            ),
        ),
        migrations.AddField(
            model_name="historicalcoronakap",
            name="hiv_missed_doses",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>ART</u> medications?",
            ),
        ),
        migrations.AddField(
            model_name="historicalcoronakap",
            name="household_size",
            field=models.IntegerField(
                default=0,
                help_text="Family / people who spend more than 14 nights per month in your home.",
                verbose_name="How many people live together in your home / dwelling?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalcoronakap",
            name="hypertensive_missed_doses",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>hypertension</u> medications?",
            ),
        ),
        migrations.AddField(
            model_name="historicalcoronakap",
            name="nights_away",
            field=models.IntegerField(
                default=0,
                help_text="e.g. travelling for work, staying with family",
                verbose_name="In the last one month, how many nights did you spend away from your home / dwelling?",
            ),
            preserve_default=False,
        ),
    ]
