
{% if not eligible %}
<div class="btn-group">
<a type="button" class="btn btn-sm btn-default dropdown-toggle" data-toggle="dropdown">
{{ display_label }}{% if comment %} <span class="caret"></span>{% endif %}
</a>
{% if comment %}
<ul class="dropdown-menu" role="menu">
	{% for line in comment %}
		<li><a href="#"><small>{{ line }}</small></a></li>
	{% endfor %}
</ul>
{% endif %}
</div>
{% endif %}
