{% load i18n %}

{%  translate "Note: If the patient is" %} <i>{%  translate "deceased" %}</i>, {%  translate "complete form" %} `{{ death_report }}` {%  translate "before completing this form" %}. <BR>{%  translate "If the patient is <i>lost to follow up</i>, complete form" %} `{{ ltfu }}` {%  translate "before completing this form." %}
