# Generated by Django 5.1.2 on 2025-01-15 13:29

import edc_sites.managers
import edc_visit_schedule.model_mixins.on_schedule_model_mixin
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0059_alter_historicaloffstudymedication_reason_and_more"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="onschedule",
            managers=[
                (
                    "objects",
                    edc_visit_schedule.model_mixins.on_schedule_model_mixin.OnScheduleManager(),
                ),
                ("on_site", edc_sites.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="onscheduledmreferral",
            managers=[
                (
                    "objects",
                    edc_visit_schedule.model_mixins.on_schedule_model_mixin.OnScheduleManager(),
                ),
                ("on_site", edc_sites.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="onschedulepostnatal",
            managers=[
                (
                    "objects",
                    edc_visit_schedule.model_mixins.on_schedule_model_mixin.OnScheduleManager(),
                ),
                ("on_site", edc_sites.managers.CurrentSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="onschedulepregnancy",
            managers=[
                (
                    "objects",
                    edc_visit_schedule.model_mixins.on_schedule_model_mixin.OnScheduleManager(),
                ),
                ("on_site", edc_sites.managers.CurrentSiteManager()),
            ],
        ),
    ]
