# Generated by Django 5.2.7 on 2025-10-03 21:43

from django.db import migrations


def fix_report_models(apps, schema_editor):
    note_cls = apps.get_model("edc_qareports", "Note")
    note_cls.objects.filter(report_model="onstudy_missing_values_view").update(
        report_model="meta_reports.onstudy_missing_values_view"
    )
    note_cls.objects.filter(report_model="onstudy_missing_lab_values_view").update(
        report_model="meta_reports.onstudy_missing_lab_values_view"
    )


class Migration(migrations.Migration):
    dependencies = [
        ("meta_reports", "0060_auto_20250926_0242"),
    ]

    operations = [migrations.RunPython(fix_report_models)]
